# HG changeset patch
# User Steven Hartland <steven.hartland@multiplay.co.uk>
# Date 1384878138 0
#      Tue Nov 19 16:22:18 2013 +0000
# Node ID 00392c02224909e43b6dd694723d2e8fc3e3e06f
# Parent  48d6aaf6bf30651627dde4219a74ce8f9d644672
Prevent crit error being loggged on delete of non-existent file.

Prevent http file cache from logging a critical error when a file delete
fails due to it not existing.

diff -r 48d6aaf6bf30 -r 00392c022249 src/http/ngx_http_file_cache.c
--- a/src/http/ngx_http_file_cache.c	Tue Nov 19 14:03:47 2013 +0400
+++ b/src/http/ngx_http_file_cache.c	Tue Nov 19 16:22:18 2013 +0000
@@ -1185,7 +1185,8 @@
                            "http file cache incomplete: \"%s\"",
                            tf->file.name.data);
 
-            if (ngx_delete_file(tf->file.name.data) == NGX_FILE_ERROR) {
+            if (ngx_delete_file(tf->file.name.data) == NGX_FILE_ERROR &&
+                ngx_errno != NGX_ENOENT) {
                 ngx_log_error(NGX_LOG_CRIT, c->file.log, ngx_errno,
                               ngx_delete_file_n " \"%s\" failed",
                               tf->file.name.data);
@@ -1404,7 +1405,8 @@
         ngx_log_debug1(NGX_LOG_DEBUG_HTTP, ngx_cycle->log, 0,
                        "http file cache expire: \"%s\"", name);
 
-        if (ngx_delete_file(name) == NGX_FILE_ERROR) {
+        if (ngx_delete_file(name) == NGX_FILE_ERROR &&
+            ngx_errno != NGX_ENOENT) {
             ngx_log_error(NGX_LOG_CRIT, ngx_cycle->log, ngx_errno,
                           ngx_delete_file_n " \"%s\" failed", name);
         }
@@ -1661,7 +1663,8 @@
     ngx_log_debug1(NGX_LOG_DEBUG_HTTP, ctx->log, 0,
                    "http file cache delete: \"%s\"", path->data);
 
-    if (ngx_delete_file(path->data) == NGX_FILE_ERROR) {
+    if (ngx_delete_file(path->data) == NGX_FILE_ERROR &&
+        ngx_errno != NGX_ENOENT) {
         ngx_log_error(NGX_LOG_CRIT, ctx->log, ngx_errno,
                       ngx_delete_file_n " \"%s\" failed", path->data);
     }
